package cn.bunny.filter;

import lombok.extern.slf4j.Slf4j;
import org.springframework.cloud.gateway.filter.GatewayFilterChain;
import org.springframework.cloud.gateway.filter.GlobalFilter;
import org.springframework.core.Ordered;
import org.springframework.http.server.reactive.ServerHttpRequest;
import org.springframework.http.server.reactive.ServerHttpResponse;
import org.springframework.stereotype.Component;
import org.springframework.web.server.ServerWebExchange;
import reactor.core.publisher.Mono;

@Slf4j
@Component
public class RouterGlobalFilter implements GlobalFilter, Ordered {
    @Override
    public Mono<Void> filter(ServerWebExchange exchange, GatewayFilterChain chain) {
        ServerHttpRequest request = exchange.getRequest();
        ServerHttpResponse response = exchange.getResponse();

        log.info("请求【{}】开始；开始时间：{}", request.getURI(), System.currentTimeMillis());

        // 因为异步编程，不能直接在 chain.filter(exchange) 后面写因为是异步的
        return chain.filter(exchange)
                .doFinally(result -> {
                    log.info("请求【{}】结束；开始时间：{}", request.getURI(), System.currentTimeMillis());
                });
    }

    @Override
    public int getOrder() {
        return 0;
    }
}
