package cn.bunny.config;

import com.alibaba.cloud.nacos.NacosConfigManager;
import com.alibaba.nacos.api.config.ConfigService;
import com.alibaba.nacos.api.config.listener.Listener;
import feign.Logger;
import feign.Retryer;
import org.springframework.boot.ApplicationRunner;
import org.springframework.cloud.client.loadbalancer.LoadBalanced;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Configuration;
import org.springframework.web.client.RestTemplate;

import java.util.concurrent.Executor;
import java.util.concurrent.Executors;

@Configuration
public class CloudConfiguration {

    @Bean
    @LoadBalanced// 负载均衡
    public RestTemplate restTemplate() {
        return new RestTemplate();
    }

    /**
     * 设置openFeign 日志级别
     */
    @Bean
    public Logger.Level feignLoggerLevel() {
        return Logger.Level.FULL;
    }

    /**
     * 当配置文件更新时的操作
     */
    @Bean
    public ApplicationRunner applicationRunner(NacosConfigManager nacosConfigManager) {
        return args -> {
            ConfigService configService = nacosConfigManager.getConfigService();
            configService.addListener("service-order.yml", "DEFAULT_GROUP", new Listener() {
                @Override
                public Executor getExecutor() {
                    return Executors.newFixedThreadPool(4);
                }

                @Override
                public void receiveConfigInfo(String s) {
                    System.out.println("变化的信息：" + s);
                    System.out.println("====================发送邮件。。。====================");
                }
            });
        };
    }

    /**
     * 重试机制
     */
    @Bean
    public Retryer retryer() {
        // 使用默认重试机制，根据之前设置的值配置有关
        return new Retryer.Default();
    }
}
