package cn.bunny.controller;

import cn.bunny.feign.CloudFeignClient;
import cn.bunny.properties.OrderProperties;
import com.alibaba.csp.sentinel.annotation.SentinelResource;
import io.swagger.v3.oas.annotations.Operation;
import io.swagger.v3.oas.annotations.tags.Tag;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Qualifier;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;

@RestController
@RequestMapping("/cloud1")
@Tag(name = "获取配置属性名称", description = "获取配置属性名称")
public class PropertiesController {

    @Autowired
    private OrderProperties orderProperties;

    @Qualifier("cn.bunny.feign.CloudFeignClient")
    @Autowired
    private CloudFeignClient cloudFeignClient;

    @GetMapping("config")
    @SentinelResource(value = "getConfig", fallback = "getConfigFallBack")
    @Operation(summary = "获取云端配置属性", description = "获取云端配置属性")
    public String getConfig() {
        // 也可以使用try进行捕获和处理
        // try {
        //     SphU.entry("zzz");
        // } catch (BlockException e) {
        //     throw new RuntimeException(e);
        // }
        return "timeout：" + orderProperties.getTimeout() + "；autoConfirm：" + orderProperties.getConfirm() + "；dbUrl：" + orderProperties.getDbUrl();
    }

    /**
     * 当获取速度过快时会走这个
     * Throwable 好处还可以处理业务错误也可以走这个
     */
    public String getConfigFallBack(Throwable throwable) {
        return "获取云端配置属性，操作过快。。。";
    }

    @Operation(summary = "远程调用拦截token", description = "远程调用拦截token")
    @GetMapping("product")
    public String getProduct(@RequestParam("id") Long id) {
        // TokenRequestInterceptor 会将内容放到请求头中之后在另一个微服务中查看请求头即可
        return cloudFeignClient.getProduct(id);
    }

}
